==> qtjambi-charts-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiCharts/QHCandlestickModelMapper_shell.h <==
#ifndef QHCANDLESTICKMODELMAPPER_SHELL_H
#define QHCANDLESTICKMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qhcandlestickmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QHCandlestickModelMapper_shell : public QHCandlestickModelMapper, public QtJambiShellInterface
{
public:
    QHCandlestickModelMapper_shell(QObject* parent0 = nullptr);
    ~QHCandlestickModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientation orientation() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHCandlestickModelMapper_access : public QHCandlestickModelMapper
{
    jint __qt_orientation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QHCANDLESTICKMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiCharts/QHCandlestickModelMapper_shell.h <==
#ifndef QHCANDLESTICKMODELMAPPER_SHELL_H
#define QHCANDLESTICKMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qhcandlestickmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qcandlestickseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QHCandlestickModelMapper_shell : public QHCandlestickModelMapper, public QtJambiShellInterface
{
public:
    QHCandlestickModelMapper_shell(QObject* parent0 = nullptr);
    ~QHCandlestickModelMapper_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QHCandlestickModelMapper_mshell;
    friend class QHCandlestickModelMapper_oshell;
};


class QHCandlestickModelMapper_mshell : public QHCandlestickModelMapper_shell
{
public:
    using QHCandlestickModelMapper_shell::QHCandlestickModelMapper_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QHCandlestickModelMapper_oshell : public QHCandlestickModelMapper_mshell
{
public:
    using QHCandlestickModelMapper_mshell::QHCandlestickModelMapper_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientation orientation() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHCandlestickModelMapper_access : public QHCandlestickModelMapper
{
    jint __qt_orientation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QHCANDLESTICKMODELMAPPER_SHELL_H
